@@ -147,13 +147,14 @@ def generate_dims_coords(
                 dims = dims[:i]
                 break
 
-    for idx, dim_len in enumerate(shape):
-        if (len(dims) < idx + 1) or (dims[idx] is None):
+    for i, dim_len in enumerate(shape):
+        idx = i + len([dim for dim in default_dims if dim in dims])
+        if len(dims) < idx + 1:
             dim_name = f"{var_name}_dim_{idx}"
-            if len(dims) < idx + 1:
-                dims.append(dim_name)
-            else:
-                dims[idx] = dim_name
+            dims.append(dim_name)
+        elif dims[idx] is None:
+            dim_name = f"{var_name}_dim_{idx}"
+            dims[idx] = dim_name
         dim_name = dims[idx]
         if dim_name not in coords:
             coords[dim_name] = np.arange(index_origin, dim_len + index_origin)
@@ -302,9 +303,8 @@ def dict_to_dataset(
     if dims is None:
         dims = {}
 
-    data_vars = {}
-    for key, values in data.items():
-        data_vars[key] = numpy_to_data_array(
+    data_vars = {
+        key: numpy_to_data_array(
             values,
             var_name=key,
             coords=coords,
@@ -313,6 +313,8 @@ def dict_to_dataset(
             index_origin=index_origin,
             skip_event_dims=skip_event_dims,
         )
+        for key, values in data.items()
+    }
     return xr.Dataset(data_vars=data_vars, attrs=make_attrs(attrs=attrs, library=library))
 
 
