@@ -3,7 +3,6 @@
 from collections.abc import Callable
 from numbers import Integral
 
-from matplotlib import _contour
 import numpy as np
 from bokeh.models import ColumnDataSource
 from bokeh.models.glyphs import Scatter
@@ -151,6 +150,13 @@ def plot_kde(
             glyphs.append(line)
 
     else:
+        try:
+            import contourpy
+        except ImportError as err:
+            raise ImportError(
+                "'bokeh' kde contour plots needs ContourPy installed (pip install countourpy)."
+            ) from err
+
         contour_kwargs = _init_kwargs_dict(contour_kwargs)
         contourf_kwargs = _init_kwargs_dict(contourf_kwargs)
         pcolormesh_kwargs = _init_kwargs_dict(pcolormesh_kwargs)
@@ -162,8 +168,10 @@ def plot_kde(
 
             scaled_density, *scaled_density_args = _scale_axis(density)
 
-            contour_generator = _contour.QuadContourGenerator(
-                x_x, y_y, scaled_density, None, True, 0
+            contourpy_kwargs = _init_kwargs_dict(contour_kwargs.pop("contourpy_kwargs", {}))
+            contourpy_kwargs.setdefault("name", "serial")
+            contour_generator = contourpy.contour_generator(
+                x=x_x, y=y_y, z=scaled_density, **contourpy_kwargs
             )
 
             levels = 9
@@ -199,7 +207,7 @@ def plot_kde(
                 contour_kwargs_ = contour_kwargs.copy()
                 contour_kwargs_.setdefault("line_color", color)
                 contour_kwargs_.setdefault("fill_color", color)
-                vertices, _ = contour_generator.create_filled_contour(level, level_upper)
+                vertices, _ = contour_generator.filled(level, level_upper)
                 for seg in vertices:
                     # ax.multi_polygon would be better, but input is
                     # currently not suitable
