@@ -2,7 +2,7 @@
 import warnings
 from itertools import cycle
 
-import matplotlib.gridspec as gridspec
+from matplotlib import gridspec
 import matplotlib.pyplot as plt
 import numpy as np
 from matplotlib.lines import Line2D
@@ -10,7 +10,7 @@ import matplotlib.ticker as mticker
 
 from ....stats.density_utils import get_bins
 from ...distplot import plot_dist
-from ...plot_utils import _scale_fig_size, format_coords_as_labels, make_label
+from ...plot_utils import _scale_fig_size, format_coords_as_labels
 from ...rankplot import plot_rank
 from . import backend_kwarg_defaults, backend_show, dealiase_sel_kwargs, matplotlib_kwarg_dealiaser
 
@@ -30,6 +30,7 @@ def plot_trace(
     combined,
     chain_prop,
     legend,
+    labeller,
     plot_kwargs,
     fill_kwargs,
     rug_kwargs,
@@ -191,6 +192,9 @@ def plot_trace(
     fill_kwargs = matplotlib_kwarg_dealiaser(fill_kwargs, "fill_between")
     rug_kwargs = matplotlib_kwarg_dealiaser(rug_kwargs, "scatter")
     rank_kwargs = matplotlib_kwarg_dealiaser(rank_kwargs, "bar")
+    if compact:
+        rank_kwargs.setdefault("bar_kwargs", {})
+        rank_kwargs["bar_kwargs"].setdefault("alpha", 0.2)
 
     textsize = plot_kwargs.pop("textsize", 10)
 
@@ -221,7 +225,7 @@ def plot_trace(
         spec = gridspec.GridSpec(ncols=2, nrows=len(plotters), figure=fig)
 
     # pylint: disable=too-many-nested-blocks
-    for idx, (var_name, selection, value) in enumerate(plotters):
+    for idx, (var_name, selection, isel, value) in enumerate(plotters):
         for idy in range(2):
             value = np.atleast_2d(value)
 
@@ -270,7 +274,7 @@ def plot_trace(
                 legend_labels = format_coords_as_labels(sub_data, skip_dims=("chain", "draw"))
                 legend_title = ", ".join(
                     [
-                        "{}".format(coord_name)
+                        f"{coord_name}"
                         for coord_name in sub_data.coords
                         if coord_name not in {"chain", "draw"}
                     ]
@@ -325,7 +329,10 @@ def plot_trace(
                 if circular:
                     y = 0.13 if selection else 0.12
             ax.set_title(
-                make_label(var_name, selection), fontsize=titlesize, wrap=True, y=textsize * y
+                labeller.make_label_vert(var_name, selection, isel),
+                fontsize=titlesize,
+                wrap=True,
+                y=textsize * y,
             )
             ax.tick_params(labelsize=xt_labelsize)
 
@@ -393,9 +400,7 @@ def plot_trace(
                 else:
                     line_values = np.atleast_1d(vlines).ravel()
                     if not np.issubdtype(line_values.dtype, np.number):
-                        raise ValueError(
-                            "line-positions should be numeric, found {}".format(line_values)
-                        )
+                        raise ValueError(f"line-positions should be numeric, found {line_values}")
                 if idy:
                     ax.hlines(
                         line_values,
@@ -495,7 +500,6 @@ def _plot_chains_mpl(
                     backend="matplotlib",
                     show=False,
                     is_circular=circ_var_units,
-                    circular=circular,
                 )
 
     if kind == "rank_bars" and idy:
@@ -518,6 +522,5 @@ def _plot_chains_mpl(
                 backend="matplotlib",
                 show=False,
                 is_circular=circ_var_units,
-                circular=circular,
             )
     return axes
