@@ -4,7 +4,7 @@ import numpy as np
 
 from ....stats import hdi
 from ....stats.density_utils import get_bins, histogram, kde
-from ...plot_utils import _scale_fig_size, make_label
+from ...plot_utils import _scale_fig_size
 from . import backend_kwarg_defaults, backend_show, create_axes_grid, matplotlib_kwarg_dealiaser
 
 
@@ -20,8 +20,10 @@ def plot_violin(
     shade,
     rug,
     rug_kwargs,
+    side,
     bw,
     textsize,
+    labeller,
     circular,
     hdi_prob,
     quartiles,
@@ -64,12 +66,12 @@ def plot_violin(
     ax = np.atleast_1d(ax)
 
     current_col = 0
-    for (var_name, selection, x), ax_ in zip(plotters, ax.flatten()):
+    for (var_name, selection, isel, x), ax_ in zip(plotters, ax.flatten()):
         val = x.flatten()
         if val[0].dtype.kind == "i":
-            dens = cat_hist(val, rug, shade, ax_, **shade_kwargs)
+            dens = cat_hist(val, rug, side, shade, ax_, **shade_kwargs)
         else:
-            dens = _violinplot(val, rug, shade, bw, circular, ax_, **shade_kwargs)
+            dens = _violinplot(val, rug, side, shade, bw, circular, ax_, **shade_kwargs)
 
         if rug:
             rug_x = -np.abs(np.random.normal(scale=max(dens) / 3.5, size=len(val)))
@@ -83,7 +85,7 @@ def plot_violin(
         ax_.plot([0, 0], hdi_probs, lw=linewidth, color="k", solid_capstyle="round")
         ax_.plot(0, per[-1], "wo", ms=linewidth * 1.5)
 
-        ax_.set_title(make_label(var_name, selection), fontsize=ax_labelsize)
+        ax_.set_title(labeller.make_label_vert(var_name, selection, isel), fontsize=ax_labelsize)
         ax_.set_xticks([])
         ax_.tick_params(labelsize=xt_labelsize)
         ax_.grid(None, axis="x")
@@ -100,24 +102,29 @@ def plot_violin(
     return ax
 
 
-def _violinplot(val, rug, shade, bw, circular, ax, **shade_kwargs):
+def _violinplot(val, rug, side, shade, bw, circular, ax, **shade_kwargs):
     """Auxiliary function to plot violinplots."""
     if bw == "default":
-        if circular:
-            bw = "taylor"
-        else:
-            bw = "experimental"
+        bw = "taylor" if circular else "experimental"
     x, density = kde(val, circular=circular, bw=bw)
 
-    if not rug:
-        x = np.concatenate([x, x[::-1]])
-        density = np.concatenate([-density, density[::-1]])
+    if rug and side == "both":
+        side = "right"
 
-    ax.fill_betweenx(x, density, alpha=shade, lw=0, **shade_kwargs)
+    if side == "left":
+        dens = -density
+    elif side == "right":
+        x = x[::-1]
+        dens = density[::-1]
+    elif side == "both":
+        x = np.concatenate([x, x[::-1]])
+        dens = np.concatenate([-density, density[::-1]])
+
+    ax.fill_betweenx(x, dens, alpha=shade, lw=0, **shade_kwargs)
     return density
 
 
-def cat_hist(val, rug, shade, ax, **shade_kwargs):
+def cat_hist(val, rug, side, shade, ax, **shade_kwargs):
     """Auxiliary function to plot discrete-violinplots."""
     bins = get_bins(val)
     _, binned_d, _ = histogram(val, bins=bins)
@@ -126,9 +133,14 @@ def cat_hist(val, rug, shade, ax, **shade_kwargs):
     heights = np.diff(bin_edges)
     centers = bin_edges[:-1] + heights.mean() / 2
 
-    if rug:
+    if rug and side == "both":
+        side = "right"
+
+    if side == "right":
         left = None
-    else:
+    elif side == "left":
+        left = -binned_d
+    elif side == "both":
         left = -0.5 * binned_d
 
     ax.barh(centers, binned_d, height=heights, left=left, alpha=shade, **shade_kwargs)
