@@ -26,26 +26,29 @@ def plot_dist_comparison(
     backend_kwargs=None,
     show=None,
 ):
-    """Plot to compare fitted and unfitted distributions.
+    r"""Plot to compare fitted and unfitted distributions.
 
     The resulting plots will show the compared distributions both on
     separate axes (particularly useful when one of them is substantially tighter
-    than another), and plotted together, so three plots per distribution
+    than another), and plotted together, displaying a grid of three plots per
+    distribution.
 
     Parameters
     ----------
-    data : InferenceData object
-        :class:`arviz.InferenceData` object containing the posterior/prior data.
-    kind : str
-        kind of plot to display {"latent", "observed"}, defaults to 'latent'.
-        "latent" includes {"prior", "posterior"} and "observed" includes
-        {"observed_data", "prior_predictive", "posterior_predictive"}
-    figsize : tuple
-        Figure size. If None it will be defined automatically.
-    textsize: float
-        Text size scaling factor for labels, titles and lines. If None it will be
-        autoscaled based on ``figsize``.
-    var_names : str, list, list of lists
+    data : InferenceData
+        Any object that can be converted to an :class:`arviz.InferenceData` object
+        containing the posterior/prior data. Refer to documentation of
+        :func:`arviz.convert_to_dataset` for details.
+    kind : {"latent", "observed"}, default "latent"
+        kind of plot to display The "latent" option includes {"prior", "posterior"},
+        and the "observed" option includes
+        {"observed_data", "prior_predictive", "posterior_predictive"}.
+    figsize : (float, float), optional
+        Figure size. If ``None`` it will be defined automatically.
+    textsize : float
+        Text size scaling factor for labels, titles and lines. If ``None`` it will be
+        autoscaled based on `figsize`.
+    var_names : str, list, list of lists, optional
         if str, plot the variable. if list, plot all the variables in list
         of all groups. if list of lists, plot the vars of groups in respective lists.
     coords : dict
@@ -54,16 +57,15 @@ def plot_dist_comparison(
         that dimension.
     combine_dims : set_like of str, optional
         List of dimensions to reduce. Defaults to reducing only the "chain" and "draw" dimensions.
-        See the :ref:`this section <common_combine_dims>` for usage examples.
-
+        See :ref:`this section <common_combine_dims>` for usage examples.
     transform : callable
-        Function to transform data (defaults to None i.e. the identity function)
+        Function to transform data (defaults to `None` i.e. the identity function).
     legend : bool
         Add legend to figure. By default True.
-    labeller : labeller instance, optional
-        Class providing the method ``make_pp_label`` to generate the labels in the plot.
+    labeller : Labeller, optional
+        Class providing the method ``make_pp_label`` to generate the labels in the plot titles.
         Read the :ref:`label_guide` for more details and usage examples.
-    ax: axes, optional
+    ax : (nvars, 3) array-like of matplotlib_axes, optional
         Matplotlib axes: The ax argument should have shape (nvars, 3), where the
         last column is for the combined before/after plots and columns 0 and 1 are
         for the before and after plots, respectively.
@@ -73,20 +75,20 @@ def plot_dist_comparison(
         Additional keywords passed to :func:`arviz.plot_dist` for posterior/predictive groups.
     observed_kwargs : dicts, optional
         Additional keywords passed to :func:`arviz.plot_dist` for observed_data group.
-    backend: str, optional
-        Select plotting backend {"matplotlib","bokeh"}. Default "matplotlib".
-    backend_kwargs: bool, optional
+    backend : {"matplotlib", "bokeh"}, default "matplotlib"
+        Select plotting backend.
+    backend_kwargs : dict, optional
         These are kwargs specific to the backend being used, passed to
-        :func:`matplotlib.pyplot.subplots` or
-        :func:`bokeh.plotting.figure`. For additional documentation
-        check the plotting method of the backend.
+        :func:`matplotlib.pyplot.subplots` or :class:`bokeh.plotting.figure`.
+        For additional documentation check the plotting method of the backend.
     show : bool, optional
         Call backend show function.
 
     Returns
     -------
-    axes : a numpy 2D array of matplotlib axes. Returned object will have shape (nvars, 3),
-    where the last column is the combined plot and the first columns are the single plots.
+    axes : 2D ndarray of matplotlib_axes
+        Returned object will have shape (nvars, 3),
+        where the last column is the combined plot and the first columns are the single plots.
 
     See Also
     --------
