@@ -24,9 +24,6 @@ def plot_pair(
     textsize=None,
     kind: Union[str, List[str]] = "scatter",
     gridsize="auto",
-    contour: Optional[bool] = None,
-    plot_kwargs=None,
-    fill_last=False,
     divergences=False,
     colorbar=False,
     labeller=None,
@@ -82,11 +79,6 @@ def plot_pair(
         such that the hexagons are approximately regular. Alternatively, gridsize
         can be a tuple with two elements specifying the number of hexagons
         in the x-direction and the y-direction.
-    contour : bool, optional, deprecated, Defaults to True.
-        If True plot the 2D KDE using contours, otherwise plot a smooth 2D KDE. Defaults to True.
-        **Note:** this default is implemented in the body of the code, not in argument processing.
-    fill_last : bool
-        If True fill the last contour of the 2D KDE plot. Defaults to True.
     divergences: Boolean
         If True divergences will be plotted in a different color, only if group is either 'prior'
         or 'posterior'.
@@ -101,7 +93,7 @@ def plot_pair(
     divergences_kwargs: dicts, optional
         Additional keywords passed to :meth:`matplotlib.axes.Axes.scatter` for divergences
     scatter_kwargs:
-        Additional keywords passed to :meth:`matplotlib.axes.Axes.plot` when using scatter kind
+        Additional keywords passed to :meth:`matplotlib.axes.Axes.scatter` when using scatter kind
     kde_kwargs: dict, optional
         Additional keywords passed to :func:`arviz.plot_kde` when using kde kind
     hexbin_kwargs: dict, optional
@@ -188,17 +180,6 @@ def plot_pair(
         kind_boolean = [kind[i] in valid_kinds for i in range(len(kind))]
     if not np.all(kind_boolean):
         raise ValueError(f"Plot type {kind} not recognized. Plot type must be in {valid_kinds}")
-    if fill_last or contour:
-        warnings.warn(
-            "fill_last and contour will be deprecated. Please use kde_kwargs",
-            UserWarning,
-        )
-    if plot_kwargs:
-        warnings.warn(
-            "plot_kwargs will be deprecated."
-            " Please use scatter_kwargs, kde_kwargs and/or hexbin_kwargs",
-            UserWarning,
-        )
 
     if coords is None:
         coords = {}
