@@ -56,9 +56,7 @@ def _make_validate_choice(accepted_values, allow_none=False, typeof=str):
             value = {"true": True, "false": False}.get(value, value)
             return value
         raise ValueError(
-            "{} is not one of {}{}".format(
-                value, accepted_values, " nor None" if allow_none else ""
-            )
+            f'{value} is not one of {accepted_values}{" nor None" if allow_none else ""}'
         )
 
     return validate_choice
@@ -95,9 +93,8 @@ def _make_validate_choice_regex(accepted_values, accepted_values_regex, allow_no
         elif any(re.match(pattern, value) for pattern in accepted_values_regex):
             return value
         raise ValueError(
-            "{} is not one of {} or in regex {}{}".format(
-                value, accepted_values, accepted_values_regex, " nor None" if allow_none else ""
-            )
+            f"{value} is not one of {accepted_values} "
+            f'or in regex {accepted_values_regex}{" nor None" if allow_none else ""}'
         )
 
     return validate_choice_regex
@@ -156,23 +153,40 @@ def _add_none_to_validator(base_validator):
 
 def _validate_bokeh_marker(value):
     """Validate the markers."""
-    all_markers = (
-        "Asterisk",
-        "Circle",
-        "CircleCross",
-        "CircleX",
-        "Cross",
-        "Dash",
-        "Diamond",
-        "DiamondCross",
-        "Hex",
-        "InvertedTriangle",
-        "Square",
-        "SquareCross",
-        "SquareX",
-        "Triangle",
-        "X",
-    )
+    try:
+        from bokeh.core.enums import MarkerType
+    except ImportError:
+        MarkerType = [
+            "asterisk",
+            "circle",
+            "circle_cross",
+            "circle_dot",
+            "circle_x",
+            "circle_y",
+            "cross",
+            "dash",
+            "diamond",
+            "diamond_cross",
+            "diamond_dot",
+            "dot",
+            "hex",
+            "hex_dot",
+            "inverted_triangle",
+            "plus",
+            "square",
+            "square_cross",
+            "square_dot",
+            "square_pin",
+            "square_x",
+            "star",
+            "star_dot",
+            "triangle",
+            "triangle_dot",
+            "triangle_pin",
+            "x",
+            "y",
+        ]
+    all_markers = list(MarkerType)
     if value not in all_markers:
         raise ValueError(f"{value} is not one of {all_markers}")
     return value
@@ -181,19 +195,18 @@ def _validate_bokeh_marker(value):
 def _validate_dict_of_lists(values):
     if isinstance(values, dict):
         return {key: tuple(item) for key, item in values.items()}
-    else:
-        validated_dict = {}
-        for value in values:
-            tup = value.split(":", 1)
-            if len(tup) != 2:
-                raise ValueError(f"Could not interpret '{value}' as key: list or str")
-            key, vals = tup
-            key = key.strip(' "')
-            vals = [val.strip(' "') for val in vals.strip(" [],").split(",")]
-            if key in validated_dict:
-                warnings.warn(f"Repeated key {key} when validating dict of lists")
-            validated_dict[key] = tuple(vals)
-        return validated_dict
+    validated_dict = {}
+    for value in values:
+        tup = value.split(":", 1)
+        if len(tup) != 2:
+            raise ValueError(f"Could not interpret '{value}' as key: list or str")
+        key, vals = tup
+        key = key.strip(' "')
+        vals = [val.strip(' "') for val in vals.strip(" [],").split(",")]
+        if key in validated_dict:
+            warnings.warn(f"Repeated key {key} when validating dict of lists")
+        validated_dict[key] = tuple(vals)
+    return validated_dict
 
 
 def make_iterable_validator(scalar_validator, length=None, allow_none=False, allow_auto=False):
@@ -278,7 +291,7 @@ defaultParams = {  # pylint: disable=invalid-name
         "above",
         _make_validate_choice({"above", "below", "left", "right"}, allow_none=True),
     ),
-    "plot.bokeh.marker": ("Cross", _validate_bokeh_marker),
+    "plot.bokeh.marker": ("cross", _validate_bokeh_marker),
     "plot.bokeh.output_backend": ("webgl", _make_validate_choice({"canvas", "svg", "webgl"})),
     "plot.bokeh.show": (True, _validate_boolean),
     "plot.bokeh.tools": (
@@ -329,8 +342,8 @@ class RcParams(MutableMapping):
             self._underlying_storage[key] = cval
         except KeyError as err:
             raise KeyError(
-                "{} is not a valid rc parameter (see rcParams.keys() for "
-                "a list of valid parameters)".format(key)
+                f"{key} is not a valid rc parameter "
+                f"(see rcParams.keys() for a list of valid parameters)"
             ) from err
 
     def __getitem__(self, key):
@@ -506,9 +519,7 @@ def read_rcfile(fname):
 
 def rc_params(ignore_files=False):
     """Read and validate arvizrc file."""
-    fname = None
-    if not ignore_files:
-        fname = get_arviz_rcfile()
+    fname = None if ignore_files else get_arviz_rcfile()
     defaults = RcParams([(key, default) for key, (default, _) in defaultParams.items()])
     if fname is not None:
         file_defaults = read_rcfile(fname)
