@@ -657,6 +657,24 @@ class TestInferenceData:  # pylint: disable=too-many-public-methods
             dataset.stack(z=["c1", "c99"]).unstack(dim="z").posterior, dataset.posterior
         )
 
+    def test_stack_bool(self):
+        datadict = {
+            "a": np.random.randn(100),
+            "b": np.random.randn(1, 100, 10),
+            "c": np.random.randn(1, 100, 3, 4),
+        }
+        coords = {
+            "c1": np.arange(3),
+            "c99": np.arange(4),
+            "b1": np.arange(10),
+        }
+        dims = {"c": ["c1", "c99"], "b": ["b1"]}
+        dataset = from_dict(posterior=datadict, coords=coords, dims=dims)
+        assert_identical(
+            dataset.stack(z=["c1", "c99"], create_index=False).posterior,
+            dataset.posterior.stack(z=["c1", "c99"], create_index=False),
+        )
+
     def test_to_dict(self, models):
         idata = models.model_1
         test_data = from_dict(**idata.to_dict())
@@ -1278,11 +1296,22 @@ class TestDataNetCDF:
 
     @pytest.mark.parametrize("groups_arg", [False, True])
     @pytest.mark.parametrize("compress", [True, False])
-    def test_io_method(self, data, eight_schools_params, groups_arg, compress):
+    @pytest.mark.parametrize("engine", ["h5netcdf", "netcdf4"])
+    def test_io_method(self, data, eight_schools_params, groups_arg, compress, engine):
         # create InferenceData and check it has been properly created
         inference_data = self.get_inference_data(  # pylint: disable=W0612
             data, eight_schools_params
         )
+        if engine == "h5netcdf":
+            try:
+                import h5netcdf  # pylint: disable=unused-import
+            except ImportError:
+                pytest.skip("h5netcdf not installed")
+        elif engine == "netcdf4":
+            try:
+                import netCDF4  # pylint: disable=unused-import
+            except ImportError:
+                pytest.skip("netcdf4 not installed")
         test_dict = {
             "posterior": ["eta", "theta", "mu", "tau"],
             "posterior_predictive": ["eta", "theta", "mu", "tau"],
